https://github.com/gak/pygooglechart/blob/master/pygooglechart.py
https://github.com/Dfenestrator/GooPyCharts/blob/master/gpcharts.py
https://github.com/justquick/google-chartwrapper
https://github.com/wikkiewikkie/flask-googlecharts/